<!doctype html>

<head>
{% block head %}

  <meta charset="utf-8">
  <meta http-equiv="X-UA-Compatible" content="IE=edge,chrome=1">
  <title>{%block title %}Dagobah{% endblock title %}</title>
  <meta name="description" content="">
  <meta name="viewport" content="width=device-width, initial-scale=1.0, maximum-scale=1, user-scalable=no">
    <style type="text/css">.hidden{margin:20px;border:5px solid #a24c4c;background-color:red;padding:10px;width:400px;color:white;font-family:helvetica,sans-serif}</style>

  <link rel="stylesheet" type="text/css" href="/static/css/kickstrap.css">
  <link rel="stylesheet" type="text/css" href="/static/css/site.css">

  <script>
    $SCRIPT_ROOT = {{ request.script_root|tojson|safe }};
  </script>

  <link rel='icon' href='/static/img/favicon.ico' type='image/x-icon' />
  <link rel='shortcut icon' href='/static/img/favicon.ico' type='image/x-icon' />

{% endblock head %}
</head>

<body>

  {% block navbar %}

  <div class='navbar navbar-fixed-top'>
    <div class='navbar-inner'>
	  <div class='container'>

	    <a class='brand' href={{ url_for('index_route') }}>Dagobah</a>

	    <ul id='navbar-left' class='nav pull-left'>
          <li id='jobs'><a href={{ url_for('jobs') }}>Jobs</a></li>
	    </ul>

	    <ul id='navbar-right' class='nav pull-right'>
          {% block navbar_current %}{% endblock navbar_current %}
          {% if current_user.is_authenticated() %}
            <li id='logout'><a href={{ url_for('do_logout') }}><i class='icon icon-off'></i></a></li>
          {% endif %}
	    </ul>

	  </div>
    </div>
  </div>

  {% endblock navbar %}

  <div class='container'>
  {% block content %}{% endblock content %}
  </div>

  <script src="//ajax.googleapis.com/ajax/libs/jquery/1.8.3/jquery.min.js"></script>
  <script>window.jQuery || document.write('<script src="/static/lib/Kickstrap1.3.0/Kickstrap/js/jquery-1.8.2.min.js"><\/script>');</script>
  <script id="appList" src="//netdna.getkickstrap.com/1.3/Kickstrap/js/kickstrap.min.js"></script>
  <script>window.consoleLog || document.write('<script id="appList" src="/static/lib/Kickstrap1.3.2/Kickstrap/js/kickstrap.min.js"><\/script>')</script>
  <script src="/static/lib/d3.v3.min.js"></script>
  <script src="/static/lib/handlebars.js"></script>
  <script src="/static/lib/moment.min.js"></script>

  <script src="/static/js/site.js"></script>
  <script src="/static/js/navbar.js"></script>

  {% block body_scripts %}{% endblock body_scripts %}

</body>

</html>
