// KICKSTRAP HEAD
// =================

   // No cache by default.
   @importedJS: "<script class=\"extras\" type=\"text/javascript\">localStorage.clear()br-consoleLog('You are currently NOT caching your styles.', 'warn')br-</script>";
   script#caching {content: @importedJS;}

   .hidden {display:none;}
   @iconSpritePath:          "./Kickstrap/bootstrap/img/glyphicons-halflings.png";
   @iconWhiteSpritePath:     "./Kickstrap/bootstrap/img/glyphicons-halflings-white.png";
