// Spacelab 2.2.2
// Bootswatch
// -----------------------------------------------------


// TYPOGRAPHY
// -----------------------------------------------------

@import url('http://fonts.googleapis.com/css?family=Open+Sans:400italic,700italic,400,700');

// SCAFFOLDING
// -----------------------------------------------------

// NAVBAR
// -----------------------------------------------------

.navbar {

	.navbar-inner {
		.box-shadow(0 1px 0 rgba(255,255,255,0.4)~", "0 1px 0 rgba(0,0,0,0.8));
	}

	.brand {

		text-shadow: 0 1px 0 rgba(255, 255, 255, 0.3);

		&:hover {
			color: @navbarLinkColorHover;
		}
	}

	.nav > li > a {
		padding: 11px 10px 8px;
		text-shadow: 0 1px 0 rgba(255, 255, 255, 0.3);
	}

	.navbar-text {
		padding: 11px 10px 8px;
		line-height: inherit;
	}

	.navbar-search .search-query,
	.navbar-search .search-query:hover {
		margin-bottom: 0;
		line-height: normal;
		color: @grayLight;
		.placeholder(@grayLight);
		.box-shadow(inset 0 1px 2px rgba(0, 0, 0, 0.5));

	    &:focus,
	    &.focused {
			.box-shadow(inset 0 1px 2px rgba(0, 0, 0, 0.5));
			color: @textColor;
		}
	}

	&-inverse {

		.brand {
			text-shadow: -1px -1px 0 rgba(0, 0, 0, 0.3);

			&:hover {
				color: @white;
			}
		}

		.nav > li > a {
			text-shadow: -1px -1px 0 rgba(0, 0, 0, 0.3);
		}

		.nav li.dropdown.open > .dropdown-toggle .caret,
		.nav li.dropdown:hover > .dropdown-toggle .caret,
		.nav li.dropdown.open:hover > .dropdown-toggle .caret {
			border-top-color: @white;
		}

		.navbar-search .search-query,
		.navbar-search .search-query:hover {

			color: @white;

			.placeholder(@grayLighter);
		}
	}
}

@media (max-width: @navbarCollapseWidth) {

	.navbar .nav-collapse {

		.nav li > a:hover {
			background-color: @linkColor;
			color: @white;
			text-shadow: none;
		}

		.navbar-search {
			border-top: none;
			border-bottom: none;
		}
	}

	.navbar-inverse .nav-collapse {

		.nav li > a {
			color: @grayLighter;

			&:hover {
				background-color: @linkColor !important;
			}
		}

		.nav-header {
			color: @grayLighter;
		}
	}
}

div.subnav {

	.nav > li > a {

		color: @navbarLinkColor;

		&:hover {
			color: @navbarLinkColorHover;
		}
	}

	.nav > li.active > a {

		color: @textColor;

		&:hover {
			color: @textColor;
		}
	}

	.nav > li.dropdown > .dropdown-toggle {
		background-color: transparent;
	}

	.nav > li.dropdown.open > .dropdown-toggle {

		border-left: 1px solid whiteSmoke;
		border-right: 1px solid #E5E5E5;
		color: @textColor;

		&:hover {
			color: @linkColor;
		}
	}
}

// NAV
// -----------------------------------------------------

.nav > li.dropdown > .dropdown-toggle,
.nav > li.dropdown.active > .dropdown-toggle,
.nav > li.dropdown.open > .dropdown-toggle,
.nav > li.dropdown.open.active > .dropdown-toggle  {

	.caret {
		border-top: 4px solid @textColor;
		border-top-color: @textColor;
		opacity: 1;
	}

	&:hover .caret {
		border-top: 4px solid @linkColorHover;
		border-top-color: @linkColorHover;
	}
}

// BUTTONS
// -----------------------------------------------------

// TABLES
// -----------------------------------------------------

// FORMS
// -----------------------------------------------------

.control-group.warning {
	.formFieldState(#E29235, #E29235, @warningBackground);
}

.control-group.error {
	.formFieldState(#C00, #C00, @errorBackground);
}

.control-group.success {
	.formFieldState(#2BA949, #2BA949, @successBackground);
}

// DROPDOWNS
// -----------------------------------------------------

// ALERTS, LABELS, BADGES
// -----------------------------------------------------

.alert {
	
	text-shadow: 0 -1px 0 rgba(0, 0, 0, 0.25);

	h1, h2, h3, h4, h5, h6 {
		color: @white;
		font-weight: bold;
		text-shadow: 0 -1px 0 rgba(0, 0, 0, 0.25);
	}
}

.label, .badge {

	padding-top: 4px;

	&-important {
		background-color: @red;
	}

	&-warning {
		background-color: @orange;
	}

	&-success {
		background-color: @green;
	}

	&-info {
		background-color: @blue;
	}
}

// MISC
// -----------------------------------------------------

.well {
	.box-shadow(inset 1px 1px 0 rgba(0,0,0,.1));
}

.hero-unit {
	.box-shadow(inset 1px 1px 0 rgba(0,0,0,.1));
	border: 1px solid rgba(0,0,0,.1);
}

// MEDIA QUERIES
// -----------------------------------------------------
